==> cenote_0.9.1_20071020.zip: cenote/widget/google_search1/google_search1.php <==
<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4 foldmethod=marker: */
// +------------------------------------------------------------------------+
// | Application: Cenote CMS												|
// +------------------------------------------------------------------------+
// | Copyright: (c) 2007.9 Akira Tanaka										|
// +------------------------------------------------------------------------+
// | 利用に関して: /cenote.txtを参照してください。							|
// +------------------------------------------------------------------------+
// | Author: Original Author <akirat28@gmail.com>							|
// +------------------------------------------------------------------------+
//
/**
 * google_search1 class
 *
 * Google検索モジュール用ウィジット
 *
 */

class google_search1 {
	public function __construct(){

	}
	public function display(){
		$html = "
		<table bgcolor=\"#FFFFFF\" class=\"widget\">
			<tr>
				<th class=\"widget\">Google検索</th>
			<tr>
			<tr>
				<td class=\"widget\">
					<div align=\"center\">
						<form method=\"get\" action=\"http://www.google.co.jp/search\">
							<img src=\"http://www.google.com/logos/Logo_40wht.gif\"	alt=\"Google\" />
      						<input type=text name=q size=15 maxlength=255 value=\"\" />
      						<input type=hidden name=ie value=UTF-8 />
      						<input type=hidden name=oe value=UTF-8 />
      						<input type=hidden name=hl value=\"ja\" />
      						<input type=submit name=btnG value=\"Google検索\" />
						</form>
					</div>
				</td>
  			</tr>
		</table>";

		return $html;
	}
}

==> cenote_0.9.3_20071026.zip: cenote/widget/google_search1/google_search1.php <==
<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4 foldmethod=marker: */
// +------------------------------------------------------------------------+
// | Application: Cenote CMS												|
// +------------------------------------------------------------------------+
// | Copyright: (c) 2007.9 Akira Tanaka										|
// +------------------------------------------------------------------------+
// | 利用に関して: /cenote.txtを参照してください。							|
// +------------------------------------------------------------------------+
// | Author: Original Author <akirat28@gmail.com>							|
// +------------------------------------------------------------------------+
//
/**
 * google_search1 class
 *
 * Google検索モジュール用ウィジット
 *
 */

class google_search1 {
	public function __construct(){

	}
	public function display(){
		$html = "
		<table class=\"cenote_widget\">
			<tr class=\"cenote_widget\">
				<th class=\"cenote_widget\">Google検索</th>
			</tr>
			<tr class=\"cenote_widget\">
				<td  class=\"cenote_widget\">
					<div align=\"center\">
						<form method=\"get\" action=\"http://www.google.co.jp/search\">
							<img src=\"http://www.google.com/logos/Logo_40wht.gif\"	alt=\"Google\" />
      						<input type=text name=q size=15 maxlength=255 value=\"\" />
      						<input type=hidden name=ie value=UTF-8 />
      						<input type=hidden name=oe value=UTF-8 />
      						<input type=hidden name=hl value=\"ja\" />
      						<input type=submit name=btnG value=\"Google検索\" />
						</form>
					</div>
				</td>
  			</tr>
		</table>";

		return $html;
	}
}
